Learn R Programming

nsga2R (version 1.1)

nsga2R-package: Elitist Non-dominated Sorting Genetic Algorithm based on R

Description

Functions for box-constrained multiobjective optimization using the elitist non-dominated sorting genetic algorithm - NSGA-II.

Arguments

Details

Package: nsga2R
Type: Package
Version: 1.0
Date: 2013-06-12
License: LGPL-3

This package provide functions for box-constrained multiobjective optimization using the elitist non-dominated sorting genetic algorithm - NSGA-II. Fast non-dominated sorting, crowding distance, tournament selection, simulated binary crossover, and polynomial mutation are called in the main program, nsga2R, to complete the search.

References

Deb, K., Pratap, A., Agarwal, S., and Meyarivan, T. (2002), " A fast and elitist multiobjective genetic algorithm: NSGA-II", IEEE Transactions on Evolutionary Computation, 6(2), 182-197.